@@ -1,7 +1,7 @@
 #!/bin/sh
 . ./IDMETA
 P=$NAME-$VERSION
-rm -fr debian/tmp debian/cf-xulrunner17 debian/cf-xulrunner17-dev
+rm -fr debian/tmp debian/cf-xulrunner[0-9][0-9] debian/cf-xulrunner[0-9][0-9]-dev
 rm -f debian/*.log debian/files debian/*.substvars
 rm -fr $P
 mkdir $P
